@@ -113,6 +113,7 @@ struct protstream {
     /* Status Flags */
     int eof;
     int boundary; /* Type of data is about to change */
+    int fixedsize;
     char *error;
 
     /* Parameters */
@@ -182,6 +183,7 @@ extern int prot_putc(int c, struct protstream *s);
 
 /* Allocate/free the protstream structure */
 extern struct protstream *prot_new(int fd, int write);
+extern struct protstream *prot_readmap(const char *buf, uint32_t len);
 extern int prot_free(struct protstream *s);
 
 /* Set the telemetry logfile for a given protstream */
@@ -196,6 +198,7 @@ extern int prot_bytes_out(struct protstream *s);
 /* Set the SASL options for a protstream (requires authentication to
  * be complete for the given sasl_conn_t */
 extern int prot_setsasl(struct protstream *s, sasl_conn_t *conn);
+extern void prot_unsetsasl(struct protstream *s);
 
 #ifdef HAVE_SSL
 /* Set TLS options for a given protstream (requires a completed tls
